##  Viewing Scheduled Changes
If the feature is activated in the administration area, an option to toggle the scheduled changes appears in the top right of fact sheets. To view the scheduled changes, toggle this option on.
![Toggling the Scheduled Changes Feature On](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe2849cbd5bff42e28e33ed2d7a9770e2_LowRes.png)
Toggling the Scheduled Changes Feature On
Once toggled on, if there are upcoming changes due to a transformation, a Scheduled change badge will appear on the subsection header, indicating that some fact sheet attributes in the subsection have upcoming changes. Clicking the badge opens a panel on the right, displaying the relevant transformation items and their impacts on various fact sheet attributes. These impacts are grouped by initiative and sorted by execution date, starting with the earliest.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob848550086f24102b77b08378b35cbb3_LowRes.png)
Viewing Scheduled Changes
